package
Version:
v0.0.0-...-6a46f16
Opens a new window with list of versions in this module.
Published: Sep 10, 2013
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewRequest is wrapper over http.NewRequest handling json encoding
for params.
func Post(url string, params interface{}, response interface{}) error
Post is a version of http.Post accepting JSON params and returning
the same.
DoRequest a wrapper over Do handling json encoding
Source Files
¶
Click to show internal directories.
Click to hide internal directories.